==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/DependencyType.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Type of dependency.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.386Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.DependencyType")
public enum DependencyType {
    /**
     * (experimental) The dependency is required for the program/library during runtime.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    RUNTIME,
    /**
     * (experimental) The dependency is required at runtime but expected to be installed by the consumer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    PEER,
    /**
     * (experimental) The dependency is bundled and shipped with the module, so consumers are not required to install it.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    BUNDLED,
    /**
     * (experimental) The dependency is required to run the `build` task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    BUILD,
    /**
     * (experimental) The dependency is required to run the `test` task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    TEST,
    /**
     * (experimental) The dependency is required for development (e.g. IDE plugins).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    DEVENV,
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/DependencyType.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Type of dependency.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.075Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.DependencyType")
public enum DependencyType {
    /**
     * (experimental) The dependency is required for the program/library during runtime.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    RUNTIME,
    /**
     * (experimental) The dependency is required at runtime but expected to be installed by the consumer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    PEER,
    /**
     * (experimental) The dependency is bundled and shipped with the module, so consumers are not required to install it.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    BUNDLED,
    /**
     * (experimental) The dependency is required to run the <code>build</code> task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    BUILD,
    /**
     * (experimental) The dependency is required to run the <code>test</code> task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    TEST,
    /**
     * (experimental) The dependency is required for development (e.g. IDE plugins).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    DEVENV,
    /**
     * (experimental) Transient dependency that needs to be overwritten.
     * <p>
     * Available for Node packages
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    OVERRIDE,
    /**
     * (experimental) An optional dependency that may be used at runtime if available, but is not required.
     * <p>
     * It is expected to be installed by the consumer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    OPTIONAL,
}
